# coding: utf-8
from tapioca import (
    TapiocaAdapter, generate_wrapper_from_adapter, FormAdapterMixin)


from .resource_mapping import RESOURCE_MAPPING


class Sectigo_api_sslClientAdapter(FormAdapterMixin, TapiocaAdapter):
    api_root = 'https://secure.trust-provider.com'
    resource_mapping = RESOURCE_MAPPING

    def get_request_kwargs(self, api_params, *args, **kwargs):
        params = super(Sectigo_api_sslClientAdapter, self).get_request_kwargs(
            api_params, *args, **kwargs)

        return params

    def get_iterator_list(self, response_data):
        return response_data

    def get_iterator_next_request_kwargs(self, iterator_request_kwargs,
                                         response_data, response):
        pass


Sectigo_api_ssl = generate_wrapper_from_adapter(Sectigo_api_sslClientAdapter)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os
import re
import sys

try:
    import pypandoc
    readme = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    readme = ''


package = 'tapioca_sectigo_api_ssl'
requirements = [
    'tapioca-wrapper<2',

]
test_requirements = [

]


def get_version(package):
    """
    Return package version as listed in `__version__` in `init.py`.
    """
    init_py = open(os.path.join(package, '__init__.py')).read()
    return re.search("^__version__ = ['\"]([^'\"]+)['\"]",
                     init_py, re.MULTILINE).group(1)


def get_author(package):
    """
    Return package author as listed in `__author__` in `init.py`.
    """
    init_py = open(os.path.join(package, '__init__.py')).read()
    return re.search("^__author__ = ['\"]([^'\"]+)['\"]",
                     init_py, re.MULTILINE).group(1)


def get_email(package):
    """
    Return package email as listed in `__email__` in `init.py`.
    """
    init_py = open(os.path.join(package, '__init__.py')).read()
    return re.search("^__email__ = ['\"]([^'\"]+)['\"]",
                     init_py, re.MULTILINE).group(1)


# python setup.py register
if sys.argv[-1] == 'publish':
    os.system("python setup.py sdist upload")
    args = {'version': get_version(package)}
    print("You probably want to also tag the version now:")
    print("  git tag -a %(version)s -m 'version %(version)s'" % args)
    print("  git push --tags")
    sys.exit()


setup(
    name='tapioca-sectigo_api_ssl',
    version=get_version(package),
    description='sectigo_api_ssl API wrapper using tapioca',
    long_description=readme,
    author=get_author(package),
    author_email=get_email(package),
    url='https://github.com/Smogin/tapioca-sectigo_api_ssl',
    packages=[
        'tapioca_sectigo_api_ssl',
    ],
    package_dir={'tapioca_sectigo_api_ssl': 'tapioca_sectigo_api_ssl'},
    include_package_data=True,
    install_requires=requirements,
    license="MIT",
    zip_safe=False,
    keywords='sectigo_api_ssl',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    test_suite='tests',
    tests_require=test_requirements
)



# coding: utf-8

RESOURCE_MAPPING = {
    'auto_authorize': {
        'resource': '/products/!AutoAuthorize',
        'docs': 'https://secure.sectigo.com/api/pdf/reseller/AutoAuthorize%20and%20AutoReject%20v1.01.pdf',
        'methods': ['POST']
    },
    'auto_reject': {
        'resource': '/products/!AutoReject',
        'docs': 'https://secure.sectigo.com/api/pdf/reseller/AutoAuthorize%20and%20AutoReject%20v1.01.pdf',
        'methods': ['POST']
    },
    'add_server_licence': {
        'resource': '/products/!AutoAddServerLicence',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/AutoAddServerLicence.pdf',
        'methods': ['POST']
    },
    'auto_apply_ssl': {
        'resource': '/products/!AutoApplyOrder',
        'docs': 'https://sectigo.com/uploads/resources/Sectigo-AutoApplyOrder-API-v2.2.pdf',
        'methods': ['POST']
    },
    'auto_replace_ssl': {
        'resource': '/products/!AutoReplaceSSL',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/AutoReplaceSSL.pdf',
        'methods': ['POST']
    },
    'auto_revoke_ssl': {
        'resource': '/products/!AutoRevokeSSL',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/AutoRevokeSSL.pdf',
        'methods': ['POST']
    },
    'collect_ssl': {
        'resource': '/products/download/CollectSSL',
        'docs': 'https://secure.sectigo.com/api/pdf/webhostreseller/sslcertificates/CollectSSL%20v1.17.pdf',
        'methods': ['POST']
    },
    'csr_decoder': {
        'resource': '/products/!DecodeCSR',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/DecodeCSR.pdf',
        'methods': ['POST']
    },
    'dcv_email_address_list': {
        'resource': '/products/!GetDCVEmailAddressList',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/GetDCVEmailAddressList.pdf',
        'methods': ['POST']
    },
    'resend_dcv_email': {
        'resource': '/products/!ResendDCVEmail',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/ResendDCVEmail.pdf',
        'methods': ['POST']
    },
    'remove_mdc_domain': {
        'resource': '/products/!AutoRemoveMDCDomain',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/AutoRemoveMDCDomain.pdf',
        'methods': ['POST']
    },
    'ov_callback': {
        'resource': '/products/!UpdateUserOvCallback',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/UpdateUserOvCallback.pdf',
        'methods': ['POST']
    },
    'ev_click_through': {
        'resource': '/products/!UpdateUserEvClickThrough',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/UpdateUserEvClickThrough.pdf',
        'methods': ['POST']
    },
    'mdc_detail_order_status': {
        'resource': '/products/!GetMDCDomainDetails',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/GetMDCDomainDetails.pdf',
        'methods': ['POST']
    },
    'provide_ev_details': {
        'resource': '/products/!ProvideEVDetails',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/ProvideEVDetails.pdf',
        'methods': ['POST']
    },
    'single_domain_detail_order_status': {
        'resource': '/products/!GetDetailedOrderStatus',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/GetDetailedOrderStatus.pdf',
        'methods': ['POST']
    },
    'ssl_checker': {
        'resource': '/sslchecker',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/SSLChecker.pdf',
        'methods': ['GET', 'POST']
    },
    'update_dcv': {
        'resource': '/products/!AutoUpdateDCV',
        'docs': 'https://secure.sectigo.com/api/pdf/latest/AutoUpdateDCV.pdf',
        'methods': ['POST']
    },
}
